#
# other checks
# $Id: checkother.pl,v 1.7 2001/04/30 20:42:07 mharo Exp $
#

use strict;
use vars qw/%makevar %mastersites %opts $nfatal $nwarn $ninfo $prog/;
use Data::Dumper;

########################################  FUNCTIONS BELOW THIS POINT

sub workdircheck {
	if (-e "work") {
		&perror("FATAL: be sure to 'make clean' before ".
			"submitting/committing.");
	} else {
		&verbose("work directory doesn't exist");
	}
}

sub warncrud {
	my ($dir) = @_;

	my @ls = ();
	my $problem = 0;

	opendir(D, $dir) || errx(1, "opendir .");
	@ls = readdir(D);
	closedir(D);

	if (@ls <= 2) {
		&perror("FATAL: $dir: empty directory should be removed.");
		$problem = 1;
	}

	foreach my $item (@ls) {
		next if ($item =~ /^(\.|\.\.|CVS)$/);
		if ($item =~ m/^work$/) {
			&perror("WARN: $dir/$item exists and was not checked for crud");
			$problem = 1;
			next;
		}
		warncrud("$dir/$item") if (-d "$dir/$item");
		if ($item =~ /(~|\.bak)$/ || $item =~ /^#/) {
			&perror("FATAL: $dir/$item: for safety, be sure to cleanup ".
				"editor backup files before submitting/committing.");
			$problem = 1;
		} elsif ($item =~ /\.(orig|rej)$/) {
			&perror("FATAL: $dir/$item: for safety, be sure to cleanup ".
				"patch backup files before submitting/committing.");
			$problem = 1;
		}
		if ($item =~ /^\./) {
			&perror("WARN: $dir/$item: dotfiles are not preferred. ".
				"If this file is a dotfile to be installed as an example, ".
				"consider importing it as \"dot$item\".");
		}
		if ($item =~ /(^|\.)core$/) {
			&perror("FATAL: $dir/$item: for safety, be sure to cleanup ".
				"core files before committing the port.");
		}
		if (-l "$dir/$item") {
			&perror("WARN: $dir/$item: this is a symlink. ".
				"CVS will ignore it.");
		}
		if (-z "$dir/$item") {
			&perror("FATAL: $dir/$item: empty file and should be removed. ".
				"If it still needs to be there, put a dummy comment ".
				"to state that the file is intentionally left empty.");
			$problem = 1;
		}
	}

	if (! $problem) {
		&verbose("no crud found in $dir");
	}
}

########################################  FUNCTION REGISTRATION

my @func_reg = (
{
  function => \&workdircheck,
  name => "workdircheck",
  option => undef,
  enabled => 1,
  file => "none"
},
{
  function => \&warncrud,
  name => "warncrud",
  option => undef,
  enabled => 1,
  file => "none"
},
);

#print Data::Dumper->Dump([\@func_reg],['@func_reg']);
\@func_reg;
