#
# makefile related checks also
# $Id: makefile2.pl,v 1.6 2001/04/30 20:42:07 mharo Exp $
#

use strict;
use vars qw/%makevar %mastersites %opts $nfatal $nwarn $ninfo $prog/;

use LWP;
use Data::Dumper;

########################################  FUNCTIONS BELOW THIS POINT

sub urlcheck {
	my ($url) = @_;
	if ($url !~ m#^\w+://#) {
		&perror("WARN: \"$url\" doesn't appear to be a URL to me.");
	}
	if ($url !~ m#/$#) {
		&perror("FATAL: URL \"$url\" should end with \"/\".");
	}
	if ($url =~ m#://[^/]*:/#) {
		&perror("FATAL: URL \"$url\" contains extra \":\".");
	}
	if ($url =~ m#(www.freebsd.org)/~.+/#i) {
		&perror("WARN: URL \"$url\", $1 should be people.FreeBSD.org");
	}
}

sub propermansect {
	my (%vars) = @_;
	foreach my $sectname (split(/\s+/, <<EOF)) {
MAN1 MAN2 MAN3 MAN4 MAN5 MAN6 MAN7 MAN8 MAN9 MANL MANN
EOF
		$sectname =~ m/(.)$/;
		my $sect = $1;
		foreach my $page (split(/\s+/, $vars{$sectname})) {
			$page =~ m/(.+)\.(.)(\..+)?/;
			my $newsect = $2;
			if ($sect != $newsect) {
				&perror("WARN: Makefile: $page listed in $sectname");
				my $newprevlst = $vars{"MAN$sect"};
				$newprevlst =~ s/$page//;
				my $newnextlst = $vars{"MAN$newsect"};
				$newnextlst =~ s/$/ $page/;
				$newnextlst =~ s/^ //;
				&createpatch("Makefile", "^MAN$sect", "MAN$sect=\t$vars{'MAN' . $sect}", "MAN$sect=\t$newprevlst\nMAN$newsect=\t$newnextlst");
			}
		}
	}
}

# this function's params seem kinda ackward.  Oh well.
sub nouservar {
	my ($file, $varname, $varvalue) = @_;
	
	if ($varvalue ne "") {
		&perror("FATAL: $file: use of $varname is discouraged. ".
			"it is intended to be a user variable.");
	} else {
		&verbose("$varname not found in $file");
	}
}

#MICHAEL: not tested, just "ported" from portlint2 so not even checked
#         for validity
sub is_predefined {
	my($url, %predefined) = @_;
	my($site);
	my($subdir);
	if ($site = (grep($url =~ $_, keys %predefined))[0]) {
		$url =~ /$site/;
		$subdir = $';
		$subdir =~ s/\/$//;
		&perror("WARN: how about using ".
			"\${MASTER_SITE_$predefined{$site}} with ".
			"\"MASTER_SITE_SUBDIR=$subdir\", instead of \"$url\?");
	}
}

########################################  FUNCTION REGISTRATION

my @func_reg = (
#{
#  function => \&urlcheck,
#  name => "urlcheck",
#  option => undef,
#  enabled => 1,
#  file => "Makefile"
#},
#{
#  function => \&propermansect,
#  name => "propermansect",
#  option => undef,
#  enabled => 1,
#  file => "Makefile"
#},
#{
#  function => \&nouservar,
#  name => "nouservar",
#  option => undef,
#  enabled => 1,
#  file => "Makefile"
#},
#{
#  function => \&is_predefined,
#  name => "is_predefined",
#  option => undef,
#  enabled => 1,
#  file => "Makefile"
#},
);

#print Data::Dumper->Dump([\@func_reg],['@func_reg']);
\@func_reg;
